<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Grimlock_Getwid
 *
 * @author  themosaurus
 * @since   1.0.0
 * @package grimlock-getwid/inc
 */
class Grimlock_Getwid {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		load_plugin_textdomain( 'grimlock-getwid', false, 'grimlock-getwid/languages' );

		add_action( 'wp_enqueue_scripts',          array( $this, 'enqueue_scripts'             ), 10 );
		add_action( 'enqueue_block_editor_assets', array( $this, 'enqueue_block_editor_styles' ), 10 );

		add_filter( 'getwid/blocks/is_disabled', array( $this, 'disable_image_hotspot' ), 10, 2 );
	}

	/**
	 * Enqueue scripts and styles
	 */
	public function enqueue_scripts() {
		wp_enqueue_style( 'grimlock-getwid', GRIMLOCK_GETWID_PLUGIN_DIR_URL . 'assets/css/style.css', array(), GRIMLOCK_GETWID_VERSION );

		/*
		 * Load style-rtl.css instead of style.css for RTL compatibility
		 */
		wp_style_add_data( 'grimlock-getwid', 'rtl', 'replace' );
	}

	/**
	 * Registers an editor stylesheet for the plugin.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_block_editor_styles() {
		wp_enqueue_style( 'grimlock-getwid-block-editor-styles', GRIMLOCK_GETWID_PLUGIN_DIR_URL . 'assets/css/style-editor.css', array(), GRIMLOCK_GETWID_VERSION, 'all' );
	}

	/**
	 * Disable Getwid's image hotspot block to avoid conflict with Bootstrap's popper.js
	 */
	public function disable_image_hotspot( $is_disabled, $block_name ) {
		if ( 'getwid/image-hotspot' === $block_name ) {
			return true;
		}

		return $is_disabled;
	}
}
